package com.ruoyi.frequency.onlinerecord.service;

import java.math.BigDecimal;
import java.util.List;

import com.ruoyi.enums.WalletDetailEnums;
import com.ruoyi.frequency.onlinerecord.entity.OnlineRecord;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.vo.UserVo;

/**
 * 在线支付记录Service接口
 * 
 * @author liwenlong
 * @date 2024-05-18
 */
public interface OnlineRecordService extends IService<OnlineRecord>
{
    /**
     * 查询在线支付记录
     * 
     * @param id 在线支付记录主键
     * @return 在线支付记录
     */
    public OnlineRecord selectOnlineRecordById(Long id);

    /**
     * 查询在线支付记录列表
     * 
     * @param onlineRecord 在线支付记录
     * @return 在线支付记录集合
     */
    public List<OnlineRecord> selectOnlineRecordList(OnlineRecord onlineRecord);

    /**
     * 新增在线支付记录
     * 
     * @param onlineRecord 在线支付记录
     * @return 结果
     */
    public int insertOnlineRecord(OnlineRecord onlineRecord);

    /**
     * 修改在线支付记录
     * 
     * @param onlineRecord 在线支付记录
     * @return 结果
     */
    public int updateOnlineRecord(OnlineRecord onlineRecord);

    /**
     * 批量删除在线支付记录
     * 
     * @param ids 需要删除的在线支付记录主键集合
     * @return 结果
     */
    public int deleteOnlineRecordByIds(Long[] ids,Integer delFlag);

    void addOnlineRecord(UserVo userVo, Long orderId, BigDecimal price, WalletDetailEnums walletDetailEnums);
}
